@@ -649,13 +649,10 @@ rbind.extended_selection_table <- function(..., deparse.level = 1) {
   mcall <- list(...)
   X <- mcall[[1]]
   Y <- mcall[[2]]
-  
-  X <- mcall[[1]]
-  Y <- mcall[[2]]
-  
+
   if (!is_extended_selection_table(X) | !is_extended_selection_table(Y)) stop("both objects must be of class 'selection_table'")
   
-  if (!identical(attr(X, "by.song"), attr(Y, "by.song"))) stop("both objects should have been created either 'by song' or by element' (see 'by.song' argument in selection_table())")
+  if (attr(X, "by.song")[[1]] != attr(Y, "by.song")[[1]]) stop("both objects should have been created either 'by song' or by element' (see 'by.song' argument in selection_table())")
   
   if (any(paste(X$sound.files, X$selec) %in% paste(Y$sound.files, Y$selec))) stop("Some sound files/selec are found in both extended selection tables")
   
